AQUA-DUCT
=========

*Aqua-Duct* a new tool facilitating analysis of the flow of solvent
molecules in molecular dynamic simulations.

Visit our homepage at [aquaduct.pl](http://aquaduct.pl/).

## Overview

*Aqua-Duct* comprises of several applications build on top of *aquaduct* Python module:

1. *valve* - performs most of core calculations including tracing of molecules.
1. *kraken* - performs additional analysis of results.
1. *pond* - calculates pockets, hotspots, and energy profiles.

*Aqua-Duct* comes also with simple GUI interface - *valveconfig* - allowing to setup calculations in a convenient way.

## Availability

*Aqua-Duct* is licensed under
`GNU GPL v3 license <https://www.gnu.org/licenses/gpl-3.0.en.html>`.

Source code is available at [github.com/TUNNELING-GROUP/aqua-duct](https://github.com/TUNNELING-GROUP/aqua-duct/).

Summary of the most important changes is available in our [changelog](https://tunneling-group.github.io/aqua-duct/changelog.html).

## Installation

*Aqua-Duct* can be easily installed via PyPi:

    pip install aquaduct

Detailed instructions on *Aqua-Duct* installation are available at
[aquaduct.pl/installation](http://www.aquaduct.pl/installation/).

To start using Aqua-Duct type:

    valve.py --help

## Troubleshooting

If you encounter any problems with installation do not hesitate to
contact us at [info@aquaduct.pl](mailto:info@aquaduct.pl?subject=Aqua-Duct). We are **REALLY** willing to help!

You can also contact us at [github.com/TUNNELING-GROUP/aqua-duct](https://github.com/TUNNELING-GROUP/aqua-duct/).

## Documentation

Documentation can be found on our homepage [aquaduct.pl/documentation](http://aquaduct.pl/documentation/).

The most recent documentation is also available at [TUNNELING-GROUP.github.io/aqua-duct](https://TUNNELING-GROUP.github.io/aqua-duct/).
